.custom-tabs-container {
    width: 100%;
}
.custom-tabs {
    border-top-left-radius: 3px;
    padding: 0px 24px;
    border-bottom: 1px solid #d6d6d6;
}

.custom-tab {
    background-color: #5cc4e7 !important;
    color:white ;
    border-top-left-radius: 6px;
    border-top-right-radius: 6px;
    border-top: 3px solid transparent !important;
    border-left: 3px !important;
    border-right: 3px !important;
    border-bottom: 3px !important;
    padding: 12px !important;
    font-family: "system-ui";
    display: flex !important;
    align-items: center;
    justify-content: center;
}
.custom-tab--selected {
    background-color: #5cc4e7
    box-shadow: 1px 1px 0px black;
    border-left: 1px solid lightgrey !important;
    border-right: 1px solid lightgrey !important;
    border-top: 3px solid #e36209 !important;
}
